==> peaceful-progression-1.1.0-sources.jar: xen42/peacefulitems/item/DispensibleSpawnEggItem.java <==
package xen42.peacefulitems.item;

import net.minecraft.class_1299;
import net.minecraft.class_1308;
import net.minecraft.class_1799;
import net.minecraft.class_1826;
import net.minecraft.class_2315;
import net.minecraft.class_2342;
import net.minecraft.class_2347;
import net.minecraft.class_2350;
import net.minecraft.class_2357;
import net.minecraft.class_3730;
import net.minecraft.class_5712;
import org.jetbrains.annotations.Nullable;
import xen42.peacefulitems.PeacefulMod;

public class DispensibleSpawnEggItem extends class_1826 {
    protected static class_2357 createDispenseItemBehavior() {
        return new class_2347() {
            @Override
            public class_1799 method_10135(class_2342 source, class_1799 stack) {
                class_2350 direction = source.comp_1969().method_11654(class_2315.field_10918);
                class_1299<?> entityType = ((class_1826) stack.method_7909()).method_8015(stack);
                
                try {
                    entityType.method_5894(source.comp_1967(), stack, null, source.comp_1968().method_10093(direction), class_3730.field_16470, direction != class_2350.field_11036, false);
                } catch (Exception ex) {
                    field_34020.error("Error while dispensing spawn egg from dispenser at {}", source.comp_1968(), ex);
                    return class_1799.field_8037;
                }
                
                stack.method_7934(1);
                source.comp_1967().method_33596(null, class_5712.field_28738, source.comp_1968());
                return stack;
            }
        };
    }
    
    public DispensibleSpawnEggItem(class_1299<? extends class_1308> entityType, int backgroundColor, int highlightColor, class_1793 properties) {
        this(entityType, backgroundColor, highlightColor, properties, createDispenseItemBehavior());
    }
    
    public DispensibleSpawnEggItem(class_1299<? extends class_1308> entityType, int backgroundColor, int highlightColor, class_1793 properties,
                                    @Nullable class_2357 dispenseItemBehavior) {
        super(entityType, backgroundColor, highlightColor, properties);
        if (dispenseItemBehavior != null) {
            class_2315.method_10009(this, dispenseItemBehavior);
        }
    }
}

==> peaceful-progression-1.1.1-sources.jar: xen42/peacefulitems/item/DispensibleSpawnEggItem.java <==
package xen42.peacefulitems.item;

import net.minecraft.class_11580;
import net.minecraft.class_1299;
import net.minecraft.class_1799;
import net.minecraft.class_1826;
import net.minecraft.class_2315;
import net.minecraft.class_2342;
import net.minecraft.class_2347;
import net.minecraft.class_2350;
import net.minecraft.class_2357;
import net.minecraft.class_3730;
import net.minecraft.class_5712;
import net.minecraft.class_9334;
import org.jetbrains.annotations.Nullable;
import xen42.peacefulitems.PeacefulMod;

public class DispensibleSpawnEggItem extends class_1826 {
    protected static class_2357 createDispenseItemBehavior() {
        return new class_2347() {
            @Override
            public class_1799 method_10135(class_2342 source, class_1799 stack) {
                class_2350 direction = source.comp_1969().method_11654(class_2315.field_10918);
                class_1299<?> entityType = ((class_1826) stack.method_7909()).method_8015(stack);
                
                try {
                    entityType.method_5894(source.comp_1967(), stack, null, source.comp_1968().method_10093(direction), class_3730.field_16470, direction != class_2350.field_11036, false);
                } catch (Exception ex) {
                    field_34020.error("Error while dispensing spawn egg from dispenser at {}", source.comp_1968(), ex);
                    return class_1799.field_8037;
                }
                
                stack.method_7934(1);
                source.comp_1967().method_33596(null, class_5712.field_28738, source.comp_1968());
                return stack;
            }
        };
    }
    
    public DispensibleSpawnEggItem(class_1793 properties) {
        this(properties, createDispenseItemBehavior());
    }
    
    public DispensibleSpawnEggItem(class_1793 properties,
                                    @Nullable class_2357 dispenseItemBehavior) {
        super(properties);
        class_11580<class_1299<?>> entityType = this.method_57347().method_58694(class_9334.field_49609);
        class_1826.field_8914.remove(entityType);
        if (dispenseItemBehavior != null) {
            class_2315.method_10009(this, dispenseItemBehavior);
        }
    }
}
